@@ -28,24 +28,6 @@ def create_parser():
                 __version__
             )
         ),
-        usage=textwrap.dedent(
-            """\
-            ffmpeg-normalize input [input ...]
-                [-h]
-                [-o OUTPUT [OUTPUT ...]] [-of OUTPUT_FOLDER]
-                [-f] [-d] [-v] [-q] [-n] [-pr]
-                [--version]
-                [-nt {ebu,rms,peak}] [-t TARGET_LEVEL] [-p]
-                [-lrt LOUDNESS_RANGE_TARGET] [-tp TRUE_PEAK] [--offset OFFSET] [--dual-mono]
-                [-c:a AUDIO_CODEC] [-b:a AUDIO_BITRATE] [-ar SAMPLE_RATE] [-koa]
-                [-prf PRE_FILTER] [-pof POST_FILTER]
-                [-vn] [-c:v VIDEO_CODEC]
-                [-sn] [-mn] [-cn]
-                [-ei EXTRA_INPUT_OPTIONS] [-e EXTRA_OUTPUT_OPTIONS]
-                [-ofmt OUTPUT_FORMAT]
-                [-ext EXTENSION]
-        """
-        ),
         formatter_class=argparse.RawTextHelpFormatter,
         epilog=textwrap.dedent(
             """\
@@ -196,12 +178,22 @@ def create_parser():
         help=textwrap.dedent(
             """\
         EBU Loudness Range Target in LUFS (default: 7.0).
-        Range is 1.0 - 20.0.
+        Range is 1.0 - 50.0.
         """
         ),
         default=7.0,
     )
 
+    group_ebu.add_argument(
+        "--keep-loudness-range-target",
+        action="store_true",
+        help=textwrap.dedent(
+            """\
+        Keep the input loudness range target to allow for linear normalization.
+        """
+        ),
+    )
+
     group_ebu.add_argument(
         "-tp",
         "--true-peak",
@@ -244,6 +236,22 @@ def create_parser():
         ),
     )
 
+    group_ebu.add_argument(
+        "--dynamic",
+        action="store_true",
+        help=textwrap.dedent(
+            """\
+        Force dynamic normalization mode.
+
+        Instead of applying linear EBU R128 normalization, choose a dynamic
+        normalization. This is not usually recommended.
+
+        Dynamic mode will automatically change the sample rate to 192 kHz. Use
+        -ar/--sample-rate to specify a different output sample rate.
+        """
+        ),
+    )
+
     group_acodec = parser.add_argument_group("Audio Encoding")
     group_acodec.add_argument(
         "-c:a",
@@ -471,9 +479,11 @@ def main():
         print_stats=cli_args.print_stats,
         loudness_range_target=cli_args.loudness_range_target,
         # threshold=cli_args.threshold,
+        keep_loudness_range_target=cli_args.keep_loudness_range_target,
         true_peak=cli_args.true_peak,
         offset=cli_args.offset,
         dual_mono=cli_args.dual_mono,
+        dynamic=cli_args.dynamic,
         audio_codec=cli_args.audio_codec,
         audio_bitrate=cli_args.audio_bitrate,
         sample_rate=cli_args.sample_rate,
@@ -530,7 +540,7 @@ def main():
                         cli_args.output_folder
                     )
                 )
-                os.makedirs(cli_args.output_folder)
+                os.makedirs(cli_args.output_folder, exist_ok=True)
 
         if os.path.exists(output_file) and not cli_args.force:
             logger.error(
