@@ -12,7 +12,9 @@ from ._logger import setup_custom_logger
 
 logger = setup_custom_logger("ffmpeg_normalize")
 
-AUDIO_ONLY_FORMATS = ["ogg", "wav"]
+AUDIO_ONLY_FORMATS = ["ogg", "wav", "opus"]
+
+
 class MediaFile:
     """
     Class that holds a file, its streams and adjustments
@@ -294,7 +296,10 @@ class MediaFile:
                 # set codec (copy by default)
                 cmd.extend(["-c:v", self.ffmpeg_normalize.video_codec])
             else:
-                logger.warn(f"The chosen output extension {self.output_ext} does not support video/cover art. It will be disabled.")
+                if not self.ffmpeg_normalize.video_disable:
+                    logger.warn(
+                        f"The chosen output extension {self.output_ext} does not support video/cover art. It will be disabled."
+                    )
 
         # ... and map the output of the normalization filters
         for ol in output_labels:
@@ -312,12 +317,6 @@ class MediaFile:
             cmd.extend(["-b:a", str(self.ffmpeg_normalize.audio_bitrate)])
         if self.ffmpeg_normalize.sample_rate:
             cmd.extend(["-ar", str(self.ffmpeg_normalize.sample_rate)])
-        else:
-            if self.ffmpeg_normalize.normalization_type == "ebu":
-                logger.warn(
-                    "The sample rate will automatically be set to 192 kHz by the loudnorm filter. "
-                    "Specify -ar/--sample-rate to override it."
-                )
 
         # ... and subtitles
         if not self.ffmpeg_normalize.subtitle_disable:
