@@ -88,6 +88,20 @@ class AudioStream(MediaStream):
             os.path.basename(self.media_file.input_file), self.stream_id
         )
 
+    @staticmethod
+    def _constrain(number, min_range, max_range, name=None):
+        """
+        Constrain a number between two values
+        """
+        if min_range > max_range:
+            raise ValueError("min must be smaller than max")
+        result = max(min(number, max_range), min_range)
+        if result != number and name is not None:
+            logger.warning(
+                f"Constraining {name} to range of [{min_range}, {max_range}]: {number} -> {result}"
+            )
+        return result
+
     def get_stats(self):
         """
         Return statistics
@@ -310,6 +324,7 @@ class AudioStream(MediaStream):
         if (
             self.media_file.ffmpeg_normalize.loudness_range_target
             < self.loudness_statistics["ebu"]["input_lra"]
+            and not will_use_dynamic_mode
         ):
             logger.warn(
                 f"Input file had loudness range of {self.loudness_statistics['ebu']['input_lra']}, which is larger than the loudness range target ({self.media_file.ffmpeg_normalize.loudness_range_target}). "
@@ -324,15 +339,17 @@ class AudioStream(MediaStream):
                 "Specify -ar/--sample-rate to override it."
             )
 
+        stats = self.loudness_statistics["ebu"]
+
         opts = {
             "i": self.media_file.ffmpeg_normalize.target_level,
             "lra": self.media_file.ffmpeg_normalize.loudness_range_target,
             "tp": self.media_file.ffmpeg_normalize.true_peak,
-            "offset": float(self.loudness_statistics["ebu"]["target_offset"]),
-            "measured_i": float(self.loudness_statistics["ebu"]["input_i"]),
-            "measured_lra": float(self.loudness_statistics["ebu"]["input_lra"]),
-            "measured_tp": float(self.loudness_statistics["ebu"]["input_tp"]),
-            "measured_thresh": float(self.loudness_statistics["ebu"]["input_thresh"]),
+            "offset": self._constrain(float(stats["target_offset"]), -99, 99, name="target_offset"),
+            "measured_i": self._constrain(float(stats["input_i"]), -99, 0, name="input_i"),
+            "measured_lra": self._constrain(float(stats["input_lra"]), 0, 99, name="input_lra"),
+            "measured_tp": self._constrain(float(stats["input_tp"]), -99, 99, name="input_tp"),
+            "measured_thresh": self._constrain(float(stats["input_thresh"]), -99, 0, name="input_thresh"),
             "linear": "false" if self.media_file.ffmpeg_normalize.dynamic else "true",
             "print_format": "json",
         }
